"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const plugin_1 = require("@parcel/plugin");
const utils_1 = require("./utils");
const pkg = require('../package.json');
const defaultLimit = 10240;
exports.default = new plugin_1.Transformer({
    loadConfig(arg) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const json = (yield arg.config.getPackage());
            const config = Object.assign({ limit: defaultLimit }, (json[pkg.name] || {}));
            return config;
        });
    },
    transform({ asset, config }) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { limit = defaultLimit } = config;
            const file = yield (yield asset.getBuffer()).toString('binary');
            if (file.length <= limit) {
                const res = yield (0, utils_1.base64)(file, asset.filePath);
                const code = `export default "${res}";`;
                asset.type = 'js';
                asset.setCode(code);
            }
            else {
                asset.bundleBehavior = 'isolated';
            }
            return [asset];
        });
    },
    canReuseAST() {
        return false;
    },
});
//# sourceMappingURL=index.js.map